pub struct EndGatewayBlockEntity {
base: BlockEntityBase,
gateway: SyncMutex<EndGatewayState>,
}Expand description
Vanilla TheEndGatewayBlockEntity.
Fields
base: BlockEntityBasegateway: SyncMutex<EndGatewayState>Implementations
Sourceimpl EndGatewayBlockEntity
impl EndGatewayBlockEntity
Sourcepub fn new(world: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
pub fn new(world: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
Creates an End gateway block entity with vanilla default state.
Sourcepub fn is_spawning(&self) -> bool
pub fn is_spawning(&self) -> bool
Returns vanilla TheEndGatewayBlockEntity.isSpawning.
Sourcepub fn is_cooling_down(&self) -> bool
pub fn is_cooling_down(&self) -> bool
Returns vanilla TheEndGatewayBlockEntity.isCoolingDown.
Sourcepub fn exit_portal(&self) -> Option<BlockPos>
pub fn exit_portal(&self) -> Option<BlockPos>
Returns the stored gateway exit position.
Sourcepub fn exact_teleport(&self) -> bool
pub fn exact_teleport(&self) -> bool
Returns whether the stored exit is used exactly.
Sourcepub fn set_exit_position(&self, exact_position: BlockPos, exact: bool)
pub fn set_exit_position(&self, exact_position: BlockPos, exact: bool)
Sets the stored gateway exit position.
Sourcepub fn trigger_cooldown(&self, world: &World)
pub fn trigger_cooldown(&self, world: &World)
Triggers vanilla gateway cooldown and broadcasts the block event.
const fn nbt_bool(value: bool) -> i8
fn load_exit_portal(nbt: &NbtCompoundView<'_, '_>) -> Option<BlockPos>