pub struct PistonMovingBlockEntity {
base: BlockEntityBase,
moving: SyncMutex<PistonMovingState>,
}Expand description
Vanilla PistonMovingBlockEntity.
Fields
base: BlockEntityBasemoving: SyncMutex<PistonMovingState>Implementations
Sourceimpl PistonMovingBlockEntity
impl PistonMovingBlockEntity
Sourcepub fn new(world: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
pub fn new(world: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
Creates the default instance used while loading a piston block entity.
Sourcepub fn new_moving(
world: Weak<World>,
pos: BlockPos,
state: BlockStateId,
moved_state: BlockStateId,
direction: Direction,
extending: bool,
source_piston: bool,
) -> Self
pub fn new_moving( world: Weak<World>, pos: BlockPos, state: BlockStateId, moved_state: BlockStateId, direction: Direction, extending: bool, source_piston: bool, ) -> Self
Creates a moving block or source-piston entity.
Sourcepub fn is_extending(&self) -> bool
pub fn is_extending(&self) -> bool
Returns whether this block is extending.
Sourcepub fn is_source_piston(&self) -> bool
pub fn is_source_piston(&self) -> bool
Returns whether this entity represents the source piston or its head.
Sourcepub fn moved_state(&self) -> BlockStateId
pub fn moved_state(&self) -> BlockStateId
Returns the state being moved.
Sourcepub fn last_ticked(&self) -> i64
pub fn last_ticked(&self) -> i64
Returns the last game time at which this entity ticked.
Sourcepub fn movement_direction(&self) -> Direction
pub fn movement_direction(&self) -> Direction
Returns the movement direction, which reverses while retracting.
Sourcepub fn push_direction(&self) -> Direction
pub fn push_direction(&self) -> Direction
Returns the direction used for the final neighbor notification.
Sourcepub fn collision_boxes(
&self,
world: &dyn LevelReader,
pos: BlockPos,
) -> BlockCollisionBoxes
pub fn collision_boxes( &self, world: &dyn LevelReader, pos: BlockPos, ) -> BlockCollisionBoxes
Resolves the transient collision boxes at the current progress.
Sourcepub fn final_tick(&self, world: &Arc<World>) -> bool
pub fn final_tick(&self, world: &Arc<World>) -> bool
Completes an in-flight moving block before its piston starts retracting.